@@ -5,6 +5,7 @@ import sys
 import json
 import subprocess
 import re
+import pyconvox
 
 
 def Env(args,apps,parser):
@@ -25,16 +26,15 @@ def Env(args,apps,parser):
         print('Please specify the application name using --app / -a <application_name>')
 
 def SetEnv(args,apps,parser):
-    re.escape()
     if args.app:
         if args.app in apps:
             option=''
             while option not in 'Y,y,N,n'.split(','):
                 option=str(input("Would you like pyconvox to promote the new release? (Y/N): ")).strip()
                 if option == 'Y' or option == 'y':
-                    stream = os.system(f"convox env set '{args.key}={args.value}' -a {args.app} -p -w")
+                    stream = os.system(f"convox env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
                 elif option == 'N' or option == 'n':
-                    stream = os.system(f"convox env set '{args.key}={args.value}' -a {args.app}")
+                    stream = os.system(f"convox env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
                 else:
                     print("Only Y or N accepted!")
             # print(args.app)
@@ -51,11 +51,7 @@ def SetEnv(args,apps,parser):
 def Scale(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.popen(f"convox scale -a {args.app}")
-            services = str(stream.read()).strip().split('\n')
-            for line in services:
-                print(f'{line}')
-            # print(args.app)
+            stream = os.system(f"convox scale -a {args.app}")
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -65,6 +61,50 @@ def Scale(args,apps,parser):
     else:
         print('Please specify the application name using --app / -a <application_name>')
 
+def PS(args,apps,parser):
+    if args.app:
+        if args.app in apps:
+            stream = os.system(f"convox ps -a {args.app}")
+        else:
+            print("Wrong Application Name!!..\nPlease provide application name from the below")
+            for index,appname in enumerate(apps):
+                print(f"{index+1}. {appname}")
+            print()
+            parser.print_help()
+    else:
+        print('Please specify the application name using --app / -a <application_name>')
+
+def Releases(args,apps,parser):
+    if args.app:
+        if args.app in apps:
+            stream = os.system(f"convox releases -a {args.app}")
+        else:
+            print("Wrong Application Name!!..\nPlease provide application name from the below")
+            for index,appname in enumerate(apps):
+                print(f"{index+1}. {appname}")
+            print()
+            parser.print_help()
+    else:
+        print('Please specify the application name using --app / -a <application_name>')
+
+def Logs(args,apps,parser):
+    if args.app:
+        if args.app in apps:
+            stream = os.system(f"convox logs -a {args.app}")
+        else:
+            print("Wrong Application Name!!..\nPlease provide application name from the below")
+            for index,appname in enumerate(apps):
+                print(f"{index+1}. {appname}")
+            print()
+            parser.print_help()
+    else:
+        print('Please specify the application name using --app / -a <application_name>')
+
+def Instances(args,apps,parser):
+        stream = os.system(f"convox instances")
+
+
+
 def RailsC(args,apps,parser):
     if args.app:
         if args.app in apps:
@@ -88,12 +128,13 @@ def RailsC(args,apps,parser):
 
 
 def main():
-    parser = argparse.ArgumentParser(description='pyconvox - a wrapper for the convox application')
+    parser = argparse.ArgumentParser(prog="pyconvox",description='pyconvox - a wrapper for the convox application')
+    parser.add_argument("--version","-V",action="version",version=f"%(prog)s version {pyconvox.__version__}",
+    )
     subparsers = parser.add_subparsers(help='Commands')
     parser_0 = subparsers.add_parser('envset', help='set env var')
     parser_0.add_argument('--app', '-a', help='application name')
-    parser_0.add_argument('--key', '-k', help='key')
-    parser_0.add_argument('--value', '-v', help='value')
+    parser_0.add_argument('envvars', metavar='Key=Value', nargs='+',help='env var(s) Key1=Value1,Key2=Value2,...')
     parser_0.set_defaults(which='envset')
 
     parser_a = subparsers.add_parser('env', help='list env vars')
@@ -105,9 +146,25 @@ def main():
     parser_b.add_argument('--service', '-s', help='Service name')
     parser_b.set_defaults(which='railsc')
     parser_b.set_defaults(service='')
-    parser_c = subparsers.add_parser('scale', help='scale a service')
+
+    parser_c = subparsers.add_parser('scale', help='scale of a application')
     parser_c.add_argument('--app', '-a', help='application name')
     parser_c.set_defaults(which='scale')
+    
+    parser_d = subparsers.add_parser('instances', help='instances details of the rack')
+    parser_d.set_defaults(which='instances')
+    
+    parser_e = subparsers.add_parser('logs', help='logs of a service')
+    parser_e.add_argument('--app', '-a', help='application name')
+    parser_e.set_defaults(which='logs')
+    
+    parser_f = subparsers.add_parser('releases', help='releases of a application')
+    parser_f.add_argument('--app', '-a', help='application name')
+    parser_f.set_defaults(which='releases')
+    
+    parser_g = subparsers.add_parser('ps', help='processes running for application')
+    parser_g.add_argument('--app', '-a', help='application name')
+    parser_g.set_defaults(which='ps')
 
     args = parser.parse_args()
     stream = os.popen("convox apps | grep -v APP | awk '{print $1}'")
@@ -123,6 +180,14 @@ def main():
             Scale(args,apps,parser)
         elif args.which == 'envset':
             SetEnv(args,apps,parser)
+        elif args.which == 'logs':
+            Logs(args,apps,parser)
+        elif args.which == 'instances':
+            Instances(args,apps,parser)
+        elif args.which == 'releases':
+            Releases(args,apps,parser)
+        elif args.which == 'ps':
+            PS(args,apps,parser)
         else:
             parser.print_help()
 
